@@ -60,6 +60,9 @@ class BaseScript(ArgumentParserScript):
         super().__init__()
 
     def append_flow_tag(self, tag):
+        """
+        A flow tag is a tag that is transmited to children.
+        """
         self.__flow_tags.append(tag)
         self.add_job_tags(tags=[tag])
 
@@ -68,7 +71,10 @@ class BaseScript(ArgumentParserScript):
         if self.flow_id_required:
             assert not self.flow_id_required or self.flow_id, "Could not detect flow_id. Please set with --flow-id."
         if self.flow_id:
-            self.add_job_tags(tags=[f"FLOW_ID={self.flow_id}"])
+            tags = [f"FLOW_ID={self.flow_id}"]
+            if self.name:
+                tags.append(f"NAME={self.name}")
+            self.add_job_tags(tags=tags)
 
     @property
     def flow_id(self):
@@ -97,56 +103,60 @@ class BaseScript(ArgumentParserScript):
         if not self.project_id:
             self.argparser.error("Project id not provided.")
 
-        self.set_flow_id(args)
-
         self.name = args.name or self.name
+        self.set_flow_id(args)
         return args
 
     def get_project(self, project_id=None):
         return self.client.get_project(project_id or self.project_id)
 
     @dash_retry_decorator
-    def get_job_metadata(self, jobid=None):
-        """If jobid is None, get own metadata
+    def get_job_metadata(self, jobkey=None):
+        """If jobkey is None, get own metadata
         """
-        jobid = jobid or os.getenv("SHUB_JOBKEY")
-        if jobid:
-            project_id = jobid.split("/", 1)[0]
+        jobkey = jobkey or os.getenv("SHUB_JOBKEY")
+        if jobkey:
+            project_id = jobkey.split("/", 1)[0]
             project = self.get_project(project_id)
-            job = project.jobs.get(jobid)
+            job = project.jobs.get(jobkey)
             return job.metadata
         logger.warning("SHUB_JOBKEY not set: not running on ScrapyCloud.")
 
     @dash_retry_decorator
-    def get_job(self, jobid=None):
-        """If jobid is None, get own metadata
+    def get_job(self, jobkey=None):
+        """If jobkey is None, get own metadata
         """
-        jobid = jobid or os.getenv("SHUB_JOBKEY")
-        if jobid:
-            project_id = jobid.split("/", 1)[0]
+        jobkey = jobkey or os.getenv("SHUB_JOBKEY")
+        if jobkey:
+            project_id = jobkey.split("/", 1)[0]
             project = self.get_project(project_id)
-            return project.jobs.get(jobid)
+            return project.jobs.get(jobkey)
         logger.warning("SHUB_JOBKEY not set: not running on ScrapyCloud.")
 
-    def get_job_tags(self, jobid=None):
-        """If jobid is None, get own tags
+    def get_job_tags(self, jobkey=None):
+        """If jobkey is None, get own tags
         """
-        metadata = self.get_job_metadata(jobid)
+        metadata = self.get_job_metadata(jobkey)
         if metadata:
             return dict(metadata.list()).get("tags", [])
         return []
 
+    def get_keyvalue_job_tag(self, key, tags):
+        for tag in tags:
+            if tag.startswith(f"{key}="):
+                return tag.replace(f"{key}=", "")
+
     @staticmethod
     @dash_retry_decorator
     def _update_metadata(metadata, data):
         metadata.update(data)
 
-    def add_job_tags(self, jobid=None, tags=None):
-        """If jobid is None, add tags to own list of tags.
+    def add_job_tags(self, jobkey=None, tags=None):
+        """If jobkey is None, add tags to own list of tags.
         """
         if tags:
             update = False
-            job_tags = self.get_job_tags(jobid)
+            job_tags = self.get_job_tags(jobkey)
             for tag in tags:
                 if tag not in job_tags:
                     if tag.startswith("FLOW_ID="):
@@ -155,29 +165,30 @@ class BaseScript(ArgumentParserScript):
                         job_tags.append(tag)
                     update = True
             if update:
-                metadata = self.get_job_metadata(jobid)
+                metadata = self.get_job_metadata(jobkey)
                 if metadata:
                     self._update_metadata(metadata, {"tags": job_tags})
 
-    def _get_flowid_from_tags(self, jobid=None):
-        """If jobid is None, get flowid from own tags
+    def _get_flowid_from_tags(self, jobkey=None):
+        """If jobkey is None, get flowid from own tags
         """
-        for tag in self.get_job_tags(jobid):
-            if tag.startswith("FLOW_ID="):
-                return tag.replace("FLOW_ID=", "")
+        tags = self.get_job_tags(jobkey)
+        return self.get_keyvalue_job_tag("FLOW_ID", tags)
 
-    def _make_tags(self, tags):
+    def _make_children_tags(self, tags):
         tags = tags or []
         tags.extend(self.args.tag)
         if self.flow_id:
             tags.append(f"FLOW_ID={self.flow_id}")
+            if self.name:
+                tags.append(f"PARENT_NAME={self.name}")
         tags.extend(self.__flow_tags)
         return sorted(set(tags)) or None
 
     @dash_retry_decorator
     def _schedule_job(self, spider: str, tags=None, units=None, project_id=None, **kwargs):
         project = self.get_project(project_id)
-        schedule_kwargs = dict(spider=spider, add_tag=self._make_tags(tags), units=units, **kwargs,)
+        schedule_kwargs = dict(spider=spider, add_tag=self._make_children_tags(tags), units=units, **kwargs,)
         logger.info("Scheduling a job:\n%s", schedule_kwargs)
         try:
             job = project.jobs.run(**schedule_kwargs)
@@ -208,14 +219,26 @@ class BaseScript(ArgumentParserScript):
 
     @dash_retry_decorator
     def get_jobs(self, project_id=None, **kwargs):
-        return self.get_project(project_id).jobs.iter(**kwargs)
-
-    def get_owned_jobs(self, project_id=None, **kwargs):
-        assert self.flow_id, "This job doesn't have a flow id."
-        assert "has_tag" not in kwargs, "Filtering by flow id requires no extra has_tag."
-        assert "state" in kwargs, "'state' parameter must be provided."
-        kwargs["has_tag"] = [f"FLOW_ID={self.flow_id}"]
-        return self.get_jobs(project_id, **kwargs)
+        kwargs = kwargs.copy()
+        kwargs["start"] = 0
+        max_count = kwargs.get("count") or float("inf")
+        kwargs["count"] = min(1000, max_count)
+        seen = set()
+        while True:
+            count = 0
+            for job in self.get_project(project_id).jobs.iter(**kwargs):
+                count += 1
+                if job["key"] not in seen:
+                    yield job
+                    seen.add(job["key"])
+                    if len(seen) == max_count:
+                        count = 0
+                        break
+            if count < kwargs["count"]:
+                break
+            else:
+                shift = len(seen)
+                kwargs["start"] += shift
 
     @dash_retry_decorator
     def is_running(self, jobkey):
@@ -229,29 +252,26 @@ class BaseScript(ArgumentParserScript):
             return True
         return False
 
-    @dash_retry_decorator
     def is_finished(self, jobkey):
         """
         Checks whether a job is running. if so, return close_reason. Otherwise return None.
         """
-        project_id = jobkey.split("/", 1)[0]
-        project = self.get_project(project_id)
-        job = project.jobs.get(jobkey)
-        if job.metadata.get("state") == "finished":
-            return job.metadata.get("close_reason")
+        metadata = self.get_job_metadata(jobkey)
+        if metadata.get("state") == "finished":
+            return metadata.get("close_reason")
 
     @dash_retry_decorator
-    def finish(self, jobid=None, close_reason=None):
+    def finish(self, jobkey=None, close_reason=None):
         close_reason = close_reason or "finished"
-        if jobid is None:
+        if jobkey is None:
             self.close_reason = close_reason
             if close_reason == "finished":
                 return
-        jobid = jobid or os.getenv("SHUB_JOBKEY")
-        if jobid:
-            project_id = jobid.split("/", 1)[0]
+        jobkey = jobkey or os.getenv("SHUB_JOBKEY")
+        if jobkey:
+            project_id = jobkey.split("/", 1)[0]
             hsp = self.client._hsclient.get_project(project_id)
-            hsj = hsp.get_job(jobid)
+            hsj = hsp.get_job(jobkey)
             hsp.jobq.finish(hsj, close_reason=close_reason)
         else:
             logger.warning("SHUB_JOBKEY not set: not running on ScrapyCloud.")
